# Benchmark: BlazeFL

This benchmark measures the performance of [BlazeFL](https://github.com/blazefl/blazefl).

## Setup

```bash
git clone https://github.com/blazefl/blazefl.git
cd blazefl/benchmarks/blazefl-case

uv sync
```

## Usage

```bash
uv run python main.py execution_mode=MULTI_THREADED

uv run python main.py --help
```
